@@ -11,7 +11,8 @@ class AnalysisObject(object):
                  eps:float=1.0, strategy:int=0, print_level:int=1, timer:bool=True,
                  num_cpu:int=1, offset:bool=True, optimize:int=2, eigen:bool=False,
                  fix_cache:bool=True, fix_multi:bool=True, max_calls:int=-1, 
-                 max_iters:int=-1, constrain_nuis:bool=True, **kwargs):
+                 max_iters:int=-1, constrain_nuis:bool=True, batch_mode:bool=False,
+                 int_bin_precision:float=-1., **kwargs):
         
         self.model = None
         self.minimizer = None
@@ -22,7 +23,7 @@ class AnalysisObject(object):
             self.setup_parameters(fix_param, profile_param)
             self.setup_minimizer(minimizer_type, minimizer_algo, precision, eps, strategy, num_cpu,
                                  offset, optimize, eigen, max_calls, max_iters, print_level,
-                                 timer, constrain_nuis)
+                                 timer, constrain_nuis, batch_mode, int_bin_precision)
         
     def setup_model(self, filename, data_name='combData', binned_likelihood:bool=True, 
                     ws_name:Optional[str]=None, mc_name:Optional[str]=None, 
@@ -45,7 +46,7 @@ class AnalysisObject(object):
                         precision:float=0.001, eps:float=1.0, strategy:int=0, 
                         num_cpu:int=1, offset:bool=True, optimize:bool=True, eigen:bool=False,
                         max_calls:int=-1, max_iters:int=-1, print_level:int=-1, timer:bool=True,
-                        constrain_nuis:bool=True):
+                        constrain_nuis:bool=True, batch_mode:bool=False, int_bin_precision:float=-1.):
         
         minimizer = ExtendedMinimizer("minimizer", self.model.pdf, self.model.data)
         
@@ -56,7 +57,10 @@ class AnalysisObject(object):
             nll_commands.append(ROOT.RooFit.GlobalObservables(self.model.global_observables))
             nll_commands.append(ROOT.RooFit.ConditionalObservables(self.model.model_config.GetConditionalObservables()))
             #nll_commands.append(ROOT.RooFit.ExternalConstraints(ROOT.RooArgSet()))
-        
+        if hasattr(ROOT.RooFit, "BatchMode"):
+            nll_commands.append(ROOT.RooFit.BatchMode(batch_mode))
+        if hasattr(ROOT.RooFit, "IntegrateBins"):
+            nll_commands.append(ROOT.RooFit.IntegrateBins(int_bin_precision))          
         minimize_options = {
             'minimizer_type'   : minimizer_type,
             'minimizer_algo'   : minimizer_algo,
